==> org.eclipse.papyrusrt.umlrt.tooling.views.codesnippet.source_0.9.0.201703230413.jar: org/eclipse/papyrusrt/umlrt/tooling/views/codesnippet/internal/Activator.java <==
/*******************************************************************************
 * Copyright (c) 2017 Zeligsoft (2009) Limited and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Contributors:
 *   Young-Soo Roh - Initial API and implementation
 *******************************************************************************/
package org.eclipse.papyrusrt.umlrt.tooling.views.codesnippet.internal;

import org.eclipse.papyrus.infra.core.log.LogHelper;
import org.eclipse.ui.plugin.AbstractUIPlugin;
import org.osgi.framework.BundleContext;

/**
 * The activator class controls the plug-in life cycle.
 */
public class Activator extends AbstractUIPlugin {

	/**
	 * The plug-in ID.
	 */
	public static final String PLUGIN_ID = "org.eclipse.papyrusrt.umlrt.tooling.views.codesnippet"; //$NON-NLS-1$

	/**
	 * log helper.
	 */
	private static LogHelper log;

	/**
	 * The shared instance.
	 */
	private static Activator plugin;

	/**
	 * The constructor.
	 */
	public Activator() {
	}

	@Override
	public void start(BundleContext context) throws Exception {
		super.start(context);
		plugin = this;
		log = new LogHelper(this);

	}

	@Override
	public void stop(BundleContext context) throws Exception {
		plugin = null;
		log = null;
		super.stop(context);
	}

	/**
	 * Returns the shared instance.
	 *
	 * @return the shared instance
	 */
	public static Activator getDefault() {
		return plugin;
	}

	/**
	 * Log error.
	 * 
	 * @param message
	 *            message
	 * @param e
	 *            exception
	 */
	public void error(String message, Exception e) {
		log.error(message, e);
	}

	/**
	 * Log warning.
	 * 
	 * @param message
	 *            message
	 */
	public void warning(String message) {
		log.warn(message);
	}

	/**
	 * Log debug.
	 * 
	 * @param message
	 *            message
	 */
	public void debug(String message) {
		log.debug(message);
	}
}

==> org.eclipse.papyrusrt.umlrt.tooling.views.codesnippet.source_1.0.0.201707181457.jar: org/eclipse/papyrusrt/umlrt/tooling/views/codesnippet/internal/Activator.java <==
/*******************************************************************************
 * Copyright (c) 2017 Zeligsoft (2009) Limited and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Contributors:
 *   Young-Soo Roh - Initial API and implementation
 *******************************************************************************/
package org.eclipse.papyrusrt.umlrt.tooling.views.codesnippet.internal;

import org.eclipse.papyrus.infra.core.log.LogHelper;
import org.eclipse.ui.plugin.AbstractUIPlugin;
import org.osgi.framework.BundleContext;

/**
 * The activator class controls the plug-in life cycle.
 */
public class Activator extends AbstractUIPlugin {

	/**
	 * The plug-in ID.
	 */
	public static final String PLUGIN_ID = "org.eclipse.papyrusrt.umlrt.tooling.views.codesnippet"; //$NON-NLS-1$

	/**
	 * log helper.
	 */
	public static LogHelper log;

	/**
	 * The shared instance.
	 */
	private static Activator plugin;

	/**
	 * The constructor.
	 */
	public Activator() {
	}

	@Override
	public void start(BundleContext context) throws Exception {
		super.start(context);
		plugin = this;
		log = new LogHelper(this);

	}

	@Override
	public void stop(BundleContext context) throws Exception {
		plugin = null;
		log = null;
		super.stop(context);
	}

	/**
	 * Returns the shared instance.
	 *
	 * @return the shared instance
	 */
	public static Activator getDefault() {
		return plugin;
	}

	/**
	 * Log error.
	 * 
	 * @param message
	 *            message
	 * @param e
	 *            exception
	 */
	public void error(String message, Exception e) {
		log.error(message, e);
	}

	/**
	 * Log warning.
	 * 
	 * @param message
	 *            message
	 */
	public void warning(String message) {
		log.warn(message);
	}

	/**
	 * Log debug.
	 * 
	 * @param message
	 *            message
	 */
	public void debug(String message) {
		log.debug(message);
	}
}
